@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from pdm import Core
+    from pdm.core import Core
 
 
 def main(core: Core):
